@@ -24,18 +24,23 @@ class Collpay:
             "from": _from,
             "to": _to
         }
-        response = self.__make_request("get-exchange-rate", "get", data)
-        print(type(response))
-        print(response)
+        response = self.__make_request("exchange-rate", "post", data)
         return response
 
     def __make_request(self, url, method, data=None):
-        headers = {
-            "Content-Type": "application/x-www-form-urlencoded",
-            "Accept": "application/json",
-            "Accept-Language": "en",
-            "x-auth": self.__public_key
-        }
-        api_url = f"{self.__base_url}/api/{self.__api_version}/{url}"
-        response = r.request(method, api_url, headers=headers, data=data)
-        return response.json()
+        try:
+            headers = {
+                "Content-Type": "application/x-www-form-urlencoded",
+                "Accept": "application/json",
+                "Accept-Language": "en",
+                "x-auth": self.__public_key
+            }
+            api_url = f"{self.__base_url}/api/{self.__api_version}/{url}"
+            response = r.request(method, api_url, headers=headers, data=data)
+            return response.json()
+
+        except Exception as msg:
+            return {
+                "success": False,
+                "message": msg
+            }
